#!/bin/sh -e

BLUEZ_LIBS="libs"
BLUEZ_UTILS="utils"
BLUEZ_HCIDUMP="hcidump"

DIR_SRC="${PWD}"
DIR_OBJ="${PWD}/obj"
DIR_INS="${PWD}/ins"

CFG_BUILD="i686-linux"
CFG_HOST="arm-linux"
CFG_TARGET="arm-linux"

export BUILD_CC="gcc"
export CC="${CFG_TARGET}-gcc"
export CXX="${CFG_TARGET}-g++"
export AS="${CFG_TARGET}-as"
export LD="${CFG_TARGET}-ld"
export AR="${CFG_TARGET}-ar"
export NM="${CFG_TARGET}-nm"
export RANLIB="${CFG_TARGET}-ranlib"
export STRIP="${CFG_TARGET}-strip"


# $1 = src/obj path
# $2 = description
# $3 = extra configure options
do_build()
{
  mkdir -p "${DIR_OBJ}/$1"
  cd "${DIR_OBJ}/$1"

  echo "***** Configuring $2..."
  "${DIR_SRC}/$1/configure"	\
    --build="${CFG_BUILD}"	\
    --host="${CFG_HOST}"	\
    --target="${CFG_TARGET}"	\
    --prefix=""			\
    --with-bluez="${DIR_INS}"	\
    $3

  echo "***** Building $2..."
  make

  echo "***** Installing $2..."
  make install DESTDIR="${DIR_INS}"
}


do_build "${BLUEZ_LIBS}"    "BlueZ libraries"
do_build "${BLUEZ_UTILS}"   "BlueZ utilities"     --enable-test
do_build "${BLUEZ_HCIDUMP}" "BlueZ HCI dump tool"


echo "***** Stripping all BlueZ binaries..."
find "${DIR_INS}" -type f | xargs file | grep "ARM, .*, not stripped" | cut -d: -f1 | xargs -r ${STRIP}


echo "***** Results can be found in ${DIR_INS}."

# EOF
